[mutter] clutter/timeline: Add meaning to constructor argument variable name



commit 75b5e079cfc17605a2357a0ef4a4610f615fe7bb
Author: Jonas Ã…dahl <jadahl gmail com>
Date:   Fri Apr 17 08:51:27 2020 +0200

    clutter/timeline: Add meaning to constructor argument variable name
    
    Start follow the convention used in ClutterFrameClock by including the
    meaning as well as time granularity in the variable name. The
    constructor takes the intended duration of the constructed timeline in
    milli seconds, so call the constructor argument `duration_ms`. This is
    done in preparation for adding more constuctors.
    
    https://gitlab.gnome.org/GNOME/mutter/-/merge_requests/1289

 clutter/clutter/clutter-timeline.c | 8 ++++----
 clutter/clutter/clutter-timeline.h | 2 +-
 2 files changed, 5 insertions(+), 5 deletions(-)
---
diff --git a/clutter/clutter/clutter-timeline.h b/clutter/clutter/clutter-timeline.h
index 656a4c5033..d6a5dde7b2 100644
--- a/clutter/clutter/clutter-timeline.h
+++ b/clutter/clutter/clutter-timeline.h
@@ -119,7 +119,7 @@ CLUTTER_EXPORT
 GType clutter_timeline_get_type (void) G_GNUC_CONST;
 
 CLUTTER_EXPORT
-ClutterTimeline *               clutter_timeline_new                            (guint                     
msecs);
+ClutterTimeline *               clutter_timeline_new                            (guint                     
duration_ms);
 
 CLUTTER_EXPORT
 guint                           clutter_timeline_get_duration                   (ClutterTimeline          
*timeline);


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/clutter/clutter/clutter-timeline.c b/clutter/clutter/clutter-timeline.c
index cd0e795ebc..e561ecfcf4 100644
--- a/clutter/clutter/clutter-timeline.c
+++ b/clutter/clutter/clutter-timeline.c
@@ -1445,9 +1445,9 @@ clutter_timeline_clone (ClutterTimeline *timeline)
 
 /**
  * clutter_timeline_new:
  * @msecs: Duration of the timeline in milliseconds
  *
  * Creates a new #ClutterTimeline with a duration of @msecs.
  *
  * Return value: the newly created #ClutterTimeline instance. Use
  *   g_object_unref() when done using it
@@ -1455,10 +1455,10 @@ clutter_timeline_clone (ClutterTimeline *timeline)
  * Since: 0.6
  */
 ClutterTimeline *
-clutter_timeline_new (guint msecs)
+clutter_timeline_new (guint duration_ms)
 {
   return g_object_new (CLUTTER_TYPE_TIMELINE,
-                       "duration", msecs,
+                       "duration", duration_ms,
                        NULL);
 }
 
@@ -1445,9 +1445,9 @@ clutter_timeline_clone (ClutterTimeline *timeline)
 /**
  * clutter_timeline_new:
- * @msecs: Duration of the timeline in milliseconds
+ * @duration_ms: Duration of the timeline in milliseconds
  *
@@ -1445,9 +1445,9 @@ clutter_timeline_clone (ClutterTimeline *timeline)
  *
- * Creates a new #ClutterTimeline with a duration of @msecs.
+ * Creates a new #ClutterTimeline with a duration of @duration_ms milli seconds.
  *
  * Return value: the newly created #ClutterTimeline instance. Use